@@ -1,5 +1,6 @@
 import asyncio
 import binascii
+import getpass
 import gzip
 import hashlib
 import http.cookiejar
@@ -403,6 +404,14 @@ def strByTimestamp(timestamp=None, fmt=None):
     ary = time.localtime(timestamp)
     return time.strftime(fmt, ary)
 
+
+def hold(msg=None, exitValue=None):
+    msg = msg or "测试暂停，输入exit可以退出"
+    exitValue = exitValue or "exit"
+    while True:
+        if getpass.getpass(f"{msg}：") == exitValue:
+            break
+
 # ---- http
 
 
